Author: kurt.kaiser
Date: Wed Aug 22 23:38:31 2007
New Revision: 57290

Modified:
   python/branches/py3k/Modules/socketmodule.c
Log:
Fix typo in comment


Modified: python/branches/py3k/Modules/socketmodule.c
==============================================================================
--- python/branches/py3k/Modules/socketmodule.c (original)
+++ python/branches/py3k/Modules/socketmodule.c Wed Aug 22 23:38:31 2007
@@ -2207,9 +2207,9 @@
        }
        if (outlen != recvlen) {
                /* We did not read as many bytes as we anticipated, resize the
-                  string if possible and be succesful. */
+                  string if possible and be successful. */
                if (PyBytes_Resize(buf, outlen) < 0)
                        /* Oopsy, not so succesful after all. */
                        return NULL;
        }
 
@@ -2207,9 +2207,9 @@
                if (PyBytes_Resize(buf, outlen) < 0)
-                       /* Oopsy, not so succesful after all. */
+                       /* Oopsy, not so successful after all. */
                        return NULL;
        }
_______________________________________________
Python-3000-checkins mailing list
[email protected]
http://mail.python.org/mailman/listinfo/python-3000-checkins

Reply via email to